import { describe, it, expect, beforeAll } from 'vitest'
import { versionEqualOrAbove } from '../../helpers/integration'
let walletService, web3Service, lockAddress, chainId

export default ({ publicLockVersion }) => {
  if (versionEqualOrAbove(publicLockVersion, 'v7')) {
    describe('expireAndRefundFor', () => {
      let keyOwner = '0x2F883401de65129fD1C368fE3Cb26d001c4Dc583'
      let expiration
      let tokenId
      beforeAll(async () => {
        ;({ walletService, web3Service, lockAddress, chainId } =
          global.suiteData)

        // First let's get a user to buy a membership
        tokenId = await walletService.purchaseKey({
          lockAddress,
          owner: keyOwner,
        })
      })

      it('should have set an expiration for this member in the future', async () => {
        expect.assertions(1)
        const key = await web3Service.getKeyByLockForOwner(
          lockAddress,
          keyOwner,
          chainId
        )
        expiration = key.expiration

        expect(expiration).toBeGreaterThan(new Date().getTime() / 1000)
      })

      it('should expire the membership', async () => {
        expect.assertions(1)
        await walletService.expireAndRefundFor({
          lockAddress,
          keyOwner, // for lock < v10
          tokenId, // for lock v10+
        })
        const key = await web3Service.getKeyByLockForOwner(
          lockAddress,
          keyOwner,
          chainId
        )

        expect(expiration).toBeGreaterThan(key.expiration)
      })
    })
  }
}
